@@ -209,7 +209,7 @@ def model_update(
         nomitall_url = "https://staging.api.nomnomdata.com/api/1"
     else:
         nomitall_url = nomitall
-    process_help(nomitall_url, doc, nomitall_secret, doc["uuid"])
+    upload_help(nomitall_url, nomitall_secret, doc)
     icons = doc.pop("icons", {})
     if model_type == "engine":
         upload_icons(nomitall_url, icons, nomitall_secret, doc["uuid"])
@@ -228,22 +228,27 @@ def upload_icons(nomitall_url, icons, nomitall_secret, uuid):
     check_response(resp)
 
 
-def upload_help(nomitall_url, nomitall_secret, uuid, key, md_path):
-    _logger.info("Pushing md to nomitall @ : {}".format(nomitall_url))
-    openfile = fsspec.open(md_path, mode="rb")
-    with openfile as f:
-        md_file = {"md": f.read()}
-    nomitall_uri = f"{nomitall_url}/engine/upload-md/{uuid}"
-    resp = requests.post(
-        nomitall_uri, files=md_file, data={"key": key}, auth=KeyAuth(nomitall_secret)
-    )
+def upload_help(nomitall_url, nomitall_secret, doc):
+    help_files = process_help(doc)
+    _logger.info("Pushing mds to nomitall @ : {}".format(nomitall_url))
+    nomitall_uri = f"{nomitall_url}/engine/upload-md/{doc['uuid']}"
+    resp = requests.post(nomitall_uri, files=help_files, auth=KeyAuth(nomitall_secret))
     check_response(resp)
 
 
-def process_help(nomitall_url, doc, nomitall_secret, uuid, key="root"):
+def load_help_file(md_path):
+    _logger.info(f"Loading {md_path}")
+    openfile = fsspec.open(md_path, mode="rb")
+    with openfile as f:
+        md_file = f.read()
+    return md_file
+
+
+def process_help(doc, key="root"):
+    help_files = {}
     if isinstance(doc, list):
         for subele in doc:
-            process_help(nomitall_url, subele, nomitall_secret, uuid, key=key)
+            help_files.update(process_help(subele, key=key))
     if isinstance(doc, dict):
         process_help
         for k, subele in doc.items():
@@ -251,12 +256,11 @@ def process_help(nomitall_url, doc, nomitall_secret, uuid, key="root"):
                 if "file" in subele:
                     if "name" in doc:
                         key += "." + doc["name"]
-                    upload_help(nomitall_url, nomitall_secret, uuid, key, subele["file"])
+                    help_files[key] = load_help_file(subele["file"])
                     doc[k] = {"key": key}
             else:
-                process_help(
-                    nomitall_url, subele, nomitall_secret, uuid, key=".".join([key, k]),
-                )
+                help_files.update(process_help(subele, key=".".join([key, k]),))
+    return help_files
 
 
 def update_engine(nomitall_url, model, model_type, nomitall_secret):
